==> CGAL-6.0-doc_html.tar.xz: doc_html/Manual/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
"citelist.html":[6],
"configurationvariables.html":[0,4],
"configurationvariables.html#inst_boost_1_72_plus":[0,4,0,6,0],
"configurationvariables.html#inst_boost_up_2_1_69":[0,4,0,6,1],
"configurationvariables.html#installation_GLPK":[0,4,0,20],
"configurationvariables.html#installation_OpenCV":[0,4,0,18],
"configurationvariables.html#installation_SCIP":[0,4,0,19],
"configurationvariables.html#installation_additional_flags":[0,4,0,2],
"configurationvariables.html#installation_boost":[0,4,0,6],
"configurationvariables.html#installation_compiler_workarounds":[0,4,1],
"configurationvariables.html#installation_component_selection":[0,4,0,0],
"configurationvariables.html#installation_eigen":[0,4,0,13],
"configurationvariables.html#installation_esbtl":[0,4,0,14],
"configurationvariables.html#installation_flags":[0,4,0,1],
"configurationvariables.html#installation_gmp":[0,4,0,7],
"configurationvariables.html#installation_laslib":[0,4,0,17],
"configurationvariables.html#installation_leda":[0,4,0,9],
"configurationvariables.html#installation_metis":[0,4,0,15],
"configurationvariables.html#installation_misc":[0,4,0,3],
"configurationvariables.html#installation_mpfi":[0,4,0,10],
"configurationvariables.html#installation_new_tbb":[0,4,0,16,1],
"configurationvariables.html#installation_ntl":[0,4,0,12],
"configurationvariables.html#installation_old_tbb":[0,4,0,16,0],
"configurationvariables.html#installation_qt6":[0,4,0,8],
"configurationvariables.html#installation_rs":[0,4,0,11],
"configurationvariables.html#installation_summary":[0,4,0],
"configurationvariables.html#installation_tbb":[0,4,0,16],
"configurationvariables.html#installation_variables_building":[0,4,0,4],
"configurationvariables.html#installation_variables_third_party":[0,4,0,5],
"deprecated.html":[3,18],
"dev_manual.html":[3],
"devman_checks.html":[3,4],
"devman_checks.html#secchecks_categories":[3,4,0],
"devman_checks.html#secchecks_cgal_assume":[3,4,3],
"devman_checks.html#secchecks_controlling":[3,4,2],
"devman_checks.html#secchecks_req_and_rec":[3,4,5],
"devman_checks.html#secchecks_using":[3,4,1],
"devman_checks.html#secexception_handling":[3,4,4],
"devman_code_format.html":[3,1],
"devman_code_format.html#Developer_manualFilenames":[3,1,0,4],
"devman_code_format.html#Developer_manualGPLversion":[3,1,3,0],
"devman_code_format.html#Developer_manualGeneralrules":[3,1,0,0],
"devman_code_format.html#Developer_manualGeometricdatastructuresand":[3,1,0,2],
"devman_code_format.html#Developer_manualGeometricobjects":[3,1,0,1],
"devman_code_format.html#Developer_manualKerneltraits":[3,1,0,3],
"devman_code_format.html#Developer_manualLGPLversion":[3,1,3,1],
"devman_code_format.html#seccode_format":[3,1,2],
"devman_code_format.html#seccode_format_doc_req_and_rec":[3,1,4],
"devman_code_format.html#secfile_header":[3,1,3],
"devman_code_format.html#secnaming_scheme":[3,1,0],
"devman_code_format.html#secprogramming_conventions":[3,1,1],
"devman_create_and_use_a_cmakelist.html":[3,17,0],
"devman_create_and_use_a_cmakelist.html":[0,3],
"devman_create_and_use_a_cmakelist.html#secexample":[0,3,1],
"devman_create_and_use_a_cmakelist.html#secexample":[3,17,0,1],
"devman_create_and_use_a_cmakelist.html#seclink":[3,17,0,0],
"devman_create_and_use_a_cmakelist.html#seclink":[0,3,0],
"devman_create_and_use_a_cmakelist.html#subcmake":[3,17,0,1,0],
"devman_create_and_use_a_cmakelist.html#subcmake":[0,3,1,0],
"devman_create_and_use_a_cmakelist.html#subexcpp":[0,3,1,1],
"devman_create_and_use_a_cmakelist.html#subexcpp":[3,17,0,1,1],
"devman_create_cgal_CMakeLists.html":[3,17],
"devman_debugging.html":[3,13],
"devman_debugging.html#Developer_manualAnexampleTraitsclassbinary":[3,13,1,0],
"devman_debugging.html#secdebugging_cross_checker":[3,13,1],
"devman_debugging.html#secdebugging_handles_and_it":[3,13,2],
"devman_debugging.html#secgraphical_debugging":[3,13,0],
"devman_info.html":[3,16],
"devman_intro.html":[3,0],
"devman_intro.html#Developer_manualCorrectness":[3,0,0,0],
"devman_intro.html#Developer_manualEaseofUse":[3,0,0,3],
"devman_intro.html#Developer_manualEfficiency":[3,0,0,4],
"devman_intro.html#Developer_manualFlexibility":[3,0,0,2],
"devman_intro.html#Developer_manualRobustness":[3,0,0,1],
"devman_intro.html#secdesign_goals":[3,0,0],
"devman_intro.html#secoverall_design":[3,0,1],
"devman_iterators_and_circulators.html":[3,10],
"devman_iterators_and_circulators.html#Developer_manualWritingcodewithandforiterators":[3,10,2],
"devman_iterators_and_circulators.html#it_and_circit_and_circ_req_and_rec":[3,10,3],
"devman_iterators_and_circulators.html#secclass_circulator":[3,10,2,3],
"devman_iterators_and_circulators.html#secclass_iterator":[3,10,2,2],
"devman_iterators_and_circulators.html#sechandle_vs_it_vs_circ":[3,10,2,0],
"devman_iterators_and_circulators.html#secinput_and_output_iterators":[3,10,1],
"devman_iterators_and_circulators.html#secit_and_circ_code":[3,10,2,1],
"devman_iterators_and_circulators.html#seciterator_traits":[3,10,0],
"devman_kernels.html":[3,2],
"devman_kernels.html#Developer_manualKerneldesignandconventions":[3,2,1],
"devman_kernels.html#Developer_manualNumber":[3,2,2],
"devman_kernels.html#secAddingFunctionObject":[3,2,4],
"devman_kernels.html#secCartesianHomogeneousComputation":[3,2,0,0],
"devman_kernels.html#secNewKernelTraits":[3,2,3],
"devman_kernels.html#secdifferent_kernels":[3,2,0],
"devman_memory_management.html":[3,6],
"devman_memory_management.html#secallocator_macro":[3,6,0],
"devman_memory_management.html#secmemory_req_and_rec":[3,6,2],
"devman_memory_management.html#secusing_memory_allocator":[3,6,1],
"devman_multithreading.html":[3,8],
"devman_multithreading.html#Developer_manualMutex":[3,8,1],
"devman_multithreading.html#Developer_manualThreadlocal":[3,8,0],
"devman_namespaces.html":[3,7],
"devman_namespaces.html#Developer_manualNamespaceCGAL":[3,7,0],
"devman_namespaces.html#Developer_manualNamespaceinternal":[3,7,1],
"devman_namespaces.html#Developer_manualNoteonglobaltemplatefunctions":[3,7,2],
"devman_namespaces.html#Developer_manualRequirementsandrecommendations_1":[3,7,3],
"devman_polyret.html":[3,9],
"devman_portability.html":[3,12],
"devman_portability.html#secboost_support":[3,12,1],
"devman_portability.html#secleda_gmp_support":[3,12,0],
"devman_portability.html#secportability_req_and_rec":[3,12,5],
"devman_portability.html#secproblems_and_workarounds":[3,12,4],
"devman_portability.html#secusing_version_macros":[3,12,2],
"devman_portability.html#secvarious_problems":[3,12,4,2],
"devman_portability.html#secwhich_compiler":[3,12,3],
"devman_portability.html#secworkaround_flags":[3,12,4,0],
"devman_portability.html#secworkaround_macros":[3,12,4,1],
"devman_reference_counting.html":[3,5],
"devman_reference_counting.html#Developer_manualAllocation":[3,5,5],
"devman_reference_counting.html#Developer_manualHandleRep":[3,5,1],
"devman_reference_counting.html#Developer_manualReferencecounting":[3,5,0],
"devman_reference_counting.html#Developer_manualTemplatedhandles":[3,5,3],
"devman_reference_counting.html#Developer_manualUsingHandleRep":[3,5,2],
"devman_reference_counting.html#Developer_manualUsingtemplatedhandles":[3,5,4],
"devman_robustness.html":[3,11],
"devman_robustness.html#Developer_manualRequirementsandrecommendations":[3,11,1],
"devman_robustness.html#Developer_manualTheroleofpredicatesandconstructions":[3,11,0],
"devman_submission.html":[3,15],
"devman_testing.html":[3,14],
"devman_testing.html#fullTestsuite":[3,14,1],
"devman_testing.html#pkgTestsuite":[3,14,0],
"devman_traits_classes.html":[3,3],
"devman_traits_classes.html#seckernel_traits":[3,3,3],
"devman_traits_classes.html#sectraits_class_example":[3,3,2],
"devman_traits_classes.html#sectraits_class_req_and_rec":[3,3,4],
"devman_traits_classes.html#secwhat_is_a_traits_class":[3,3,0],
"devman_traits_classes.html#secwhy_traits_classes":[3,3,1],
"devman_traits_classes.html#subseccgal_traits_classes":[3,3,2,1],
"devman_traits_classes.html#subsectraits_class_requirements":[3,3,2,0],
"general_intro.html":[0],
"how_to_cite_cgal.html":[5],
"index.html":[],
"installation.html":[0,5],
"installation.html#installation_buildprogram":[0,5,4],
"installation.html#installation_cgalconfig":[0,5,1,6],
"installation.html#installation_configuring_cmd":[0,5,1,5],
"installation.html#installation_configuring_gui":[0,5,1,4],
"installation.html#installation_configwithcmake":[0,5,1],
"installation.html#installation_debugrelease":[0,5,1,2],
"installation.html#installation_examples":[0,5,1,1],
"installation.html#installation_idealworld":[0,5,0],
"installation.html#installation_miscvariables":[0,5,1,3],
"installation.html#seccmakeoutofsource":[0,5,2],
"installation.html#secinstalling":[0,5,3],
"installation.html#seclibraries":[0,5,1,0],
"installation.html#ssec_installation_build_ex_demos":[0,5,2,0],
"license.html":[0,8],
"license.html":[4],
"license.html#licenseCheck":[0,8,4],
"license.html#licenseCheck":[4,4],
"license.html#licensesCommercial":[4,3],
"license.html#licensesCommercial":[0,8,3],
"license.html#licensesGPL":[0,8,0],
"license.html#licensesGPL":[4,0],
"license.html#licensesLGPL":[0,8,1],
"license.html#licensesLGPL":[4,1],
"license.html#licensesRationale":[4,2],
"license.html#licensesRationale":[0,8,2],
"license.html#licensesWhere":[0,8,5],
"license.html#licensesWhere":[4,5],
"manual.html":[0,6],
"manual.html#advanced_features":[0,6,2,0],
"manual.html#debugging_support":[0,6,2,1],
"manual.html#deprecated_code":[0,6,2,2],
"manual.html#markingSpecialFunctionality":[0,6,2],
"manual.html#secorganization":[0,6,0],
"manual.html#secorganizationref":[0,6,1],
"packages.html":[2],
"packages.html#Miscellany":[2,15,8],
"packages.html#PartAlgebraicFoundations":[2,0],
"packages.html#PartArrangements":[2,6],
"packages.html#PartCombinatorialAlgorithms":[2,1],
"packages.html#PartConvexHullAlgorithms":[2,3],
"packages.html#PartGeometricOptimization":[2,13],
"packages.html#PartGeometryProcessing":[2,11],
"packages.html#PartInterpolation":[2,14],
"packages.html#PartKernels":[2,2],
"packages.html#PartMeshing":[2,9],
"packages.html#PartPolygons":[2,4],
"packages.html#PartPolyhedra":[2,5],
"packages.html#PartReconstruction":[2,10],
"packages.html#PartSearchStructures":[2,12],
"packages.html#PartSupportLibrary":[2,15],
"packages.html#PartTriangulationsAndDelaunayTriangulations":[2,7],
"packages.html#PartVisualization":[2,16],
"packages.html#PartVoronoiDiagrams":[2,8],
"packages.html#PkgAABBTree":[2,12,5],
"packages.html#PkgAdvancingFrontSurfaceReconstruction":[2,10,2],
"packages.html#PkgAlgebraicFoundations":[2,0,0],
"packages.html#PkgAlgebraicKernelD":[2,0,4],
"packages.html#PkgAlphaShapes2":[2,7,10],
"packages.html#PkgAlphaShapes3":[2,7,11],
"packages.html#PkgAlphaWrap3":[2,9,7],
"packages.html#PkgApolloniusGraph2":[2,8,2],
"packages.html#PkgArrangementOnSurface2":[2,6,0],
"packages.html#PkgBGL":[2,15,1],
"packages.html#PkgBarycentricCoordinates2":[2,14,1],
"packages.html#PkgBasicViewer":[2,16,2],
"packages.html#PkgBooleanSetOperations2":[2,4,2],
"packages.html#PkgBoundingVolumes":[2,13,0],
"packages.html#PkgBoxIntersectionD":[2,12,4],
"packages.html#PkgCGALIpelets":[2,16,1],
"packages.html#PkgCircularKernel2":[2,2,2],
"packages.html#PkgCircularKernel3":[2,2,3],
"packages.html#PkgClassification":[2,11,16],
"packages.html#PkgCombinatorialMaps":[2,5,3],
"packages.html#PkgConeSpanners2":[2,15,5],
"packages.html#PkgConvexDecomposition3":[2,5,7],
"packages.html#PkgConvexHull2":[2,3,0],
"packages.html#PkgConvexHull3":[2,3,1],
"packages.html#PkgConvexHullD":[2,3,2],
"packages.html#PkgEnvelope2":[2,6,3],
"packages.html#PkgEnvelope3":[2,6,4],
"packages.html#PkgGeneralizedMaps":[2,5,4],
"packages.html#PkgGenerators":[2,15,7],
"packages.html#PkgGraphicsView":[2,16,0],
"packages.html#PkgHalfedgeDS":[2,5,1],
"packages.html#PkgHandlesAndCirculators":[2,15,6],
"packages.html#PkgHeatMethod":[2,11,17],
"packages.html#PkgHyperbolicTriangulation2":[2,7,4],
"packages.html#PkgInscribedAreas":[2,13,1],
"packages.html#PkgInterpolation2":[2,14,0],
"packages.html#PkgIntervalSkipList":[2,12,1],
"packages.html#PkgJetFitting3":[2,11,10],
"packages.html#PkgKernel23":[2,2,0],
"packages.html#PkgKernelD":[2,2,1],
"packages.html#PkgKineticSpacePartition":[2,10,4],
"packages.html#PkgKineticSurfaceReconstruction":[2,10,5],
"packages.html#PkgLinearCellComplex":[2,5,5],
"packages.html#PkgMatrixSearch":[2,1,0],
"packages.html#PkgMesh2":[2,9,0],
"packages.html#PkgMesh3":[2,9,4],
"packages.html#PkgMinkowskiSum2":[2,4,7],
"packages.html#PkgMinkowskiSum3":[2,5,8],
"packages.html#PkgModularArithmetic":[2,0,2],
"packages.html#PkgNef2":[2,4,3],
"packages.html#PkgNef3":[2,5,6],
"packages.html#PkgNefS2":[2,4,4],
"packages.html#PkgNumberTypes":[2,0,1],
"packages.html#PkgOptimalBoundingBox":[2,13,4],
"packages.html#PkgOptimalTransportationReconstruction2":[2,10,6],
"packages.html#PkgOrthtree":[2,12,6]
};

==> CGAL-6.1-doc_html.tar.xz: doc_html/Manual/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
"citelist.html":[7],
"configurationvariables.html":[0,4],
"configurationvariables.html#installation_GLPK":[0,4,0,20],
"configurationvariables.html#installation_OpenCV":[0,4,0,18],
"configurationvariables.html#installation_SCIP":[0,4,0,19],
"configurationvariables.html#installation_additional_flags":[0,4,0,2],
"configurationvariables.html#installation_boost":[0,4,0,6],
"configurationvariables.html#installation_compiler_workarounds":[0,4,1],
"configurationvariables.html#installation_component_selection":[0,4,0,0],
"configurationvariables.html#installation_eigen":[0,4,0,13],
"configurationvariables.html#installation_esbtl":[0,4,0,14],
"configurationvariables.html#installation_flags":[0,4,0,1],
"configurationvariables.html#installation_gmp":[0,4,0,7],
"configurationvariables.html#installation_laslib":[0,4,0,17],
"configurationvariables.html#installation_leda":[0,4,0,9],
"configurationvariables.html#installation_metis":[0,4,0,15],
"configurationvariables.html#installation_misc":[0,4,0,3],
"configurationvariables.html#installation_mpfi":[0,4,0,10],
"configurationvariables.html#installation_new_tbb":[0,4,0,16,1],
"configurationvariables.html#installation_ntl":[0,4,0,12],
"configurationvariables.html#installation_old_tbb":[0,4,0,16,0],
"configurationvariables.html#installation_qt6":[0,4,0,8],
"configurationvariables.html#installation_rs":[0,4,0,11],
"configurationvariables.html#installation_summary":[0,4,0],
"configurationvariables.html#installation_tbb":[0,4,0,16],
"configurationvariables.html#installation_variables_building":[0,4,0,4],
"configurationvariables.html#installation_variables_third_party":[0,4,0,5],
"deprecated.html":[3,18],
"dev_manual.html":[3],
"devman_checks.html":[3,4],
"devman_checks.html#secchecks_categories":[3,4,0],
"devman_checks.html#secchecks_cgal_assume":[3,4,3],
"devman_checks.html#secchecks_controlling":[3,4,2],
"devman_checks.html#secchecks_req_and_rec":[3,4,5],
"devman_checks.html#secchecks_using":[3,4,1],
"devman_checks.html#secexception_handling":[3,4,4],
"devman_code_format.html":[3,1],
"devman_code_format.html#Developer_manualFilenames":[3,1,0,4],
"devman_code_format.html#Developer_manualGPLversion":[3,1,3,0],
"devman_code_format.html#Developer_manualGeneralrules":[3,1,0,0],
"devman_code_format.html#Developer_manualGeometricdatastructuresand":[3,1,0,2],
"devman_code_format.html#Developer_manualGeometricobjects":[3,1,0,1],
"devman_code_format.html#Developer_manualKerneltraits":[3,1,0,3],
"devman_code_format.html#Developer_manualLGPLversion":[3,1,3,1],
"devman_code_format.html#seccode_format":[3,1,2],
"devman_code_format.html#seccode_format_doc_req_and_rec":[3,1,4],
"devman_code_format.html#secfile_header":[3,1,3],
"devman_code_format.html#secnaming_scheme":[3,1,0],
"devman_code_format.html#secprogramming_conventions":[3,1,1],
"devman_create_and_use_a_cmakelist.html":[0,3],
"devman_create_and_use_a_cmakelist.html#secexample":[0,3,1],
"devman_create_and_use_a_cmakelist.html#seclink":[0,3,0],
"devman_create_and_use_a_cmakelist.html#subcmake":[0,3,1,0],
"devman_create_and_use_a_cmakelist.html#subexcpp":[0,3,1,1],
"devman_create_cgal_CMakeLists.html":[3,17],
"devman_debugging.html":[3,13],
"devman_debugging.html#Developer_manualAnexampleTraitsclassbinary":[3,13,1,0],
"devman_debugging.html#secdebugging_cross_checker":[3,13,1],
"devman_debugging.html#secdebugging_handles_and_it":[3,13,2],
"devman_debugging.html#secgraphical_debugging":[3,13,0],
"devman_info.html":[3,16],
"devman_intro.html":[3,0],
"devman_intro.html#Developer_manualCorrectness":[3,0,0,0],
"devman_intro.html#Developer_manualEaseofUse":[3,0,0,3],
"devman_intro.html#Developer_manualEfficiency":[3,0,0,4],
"devman_intro.html#Developer_manualFlexibility":[3,0,0,2],
"devman_intro.html#Developer_manualRobustness":[3,0,0,1],
"devman_intro.html#secdesign_goals":[3,0,0],
"devman_intro.html#secoverall_design":[3,0,1],
"devman_iterators_and_circulators.html":[3,10],
"devman_iterators_and_circulators.html#Developer_manualWritingcodewithandforiterators":[3,10,2],
"devman_iterators_and_circulators.html#it_and_circit_and_circ_req_and_rec":[3,10,3],
"devman_iterators_and_circulators.html#secclass_circulator":[3,10,2,3],
"devman_iterators_and_circulators.html#secclass_iterator":[3,10,2,2],
"devman_iterators_and_circulators.html#sechandle_vs_it_vs_circ":[3,10,2,0],
"devman_iterators_and_circulators.html#secinput_and_output_iterators":[3,10,1],
"devman_iterators_and_circulators.html#secit_and_circ_code":[3,10,2,1],
"devman_iterators_and_circulators.html#seciterator_traits":[3,10,0],
"devman_kernels.html":[3,2],
"devman_kernels.html#Developer_manualKerneldesignandconventions":[3,2,1],
"devman_kernels.html#Developer_manualNumber":[3,2,2],
"devman_kernels.html#secAddingFunctionObject":[3,2,4],
"devman_kernels.html#secCartesianHomogeneousComputation":[3,2,0,0],
"devman_kernels.html#secNewKernelTraits":[3,2,3],
"devman_kernels.html#secdifferent_kernels":[3,2,0],
"devman_memory_management.html":[3,6],
"devman_memory_management.html#secallocator_macro":[3,6,0],
"devman_memory_management.html#secmemory_req_and_rec":[3,6,2],
"devman_memory_management.html#secusing_memory_allocator":[3,6,1],
"devman_multithreading.html":[3,8],
"devman_multithreading.html#Developer_manualMutex":[3,8,1],
"devman_multithreading.html#Developer_manualThreadlocal":[3,8,0],
"devman_namespaces.html":[3,7],
"devman_namespaces.html#Developer_manualNamespaceCGAL":[3,7,0],
"devman_namespaces.html#Developer_manualNamespaceinternal":[3,7,1],
"devman_namespaces.html#Developer_manualNoteonglobaltemplatefunctions":[3,7,2],
"devman_namespaces.html#Developer_manualRequirementsandrecommendations_1":[3,7,3],
"devman_polyret.html":[3,9],
"devman_portability.html":[3,12],
"devman_portability.html#secboost_support":[3,12,1],
"devman_portability.html#secleda_gmp_support":[3,12,0],
"devman_portability.html#secportability_req_and_rec":[3,12,5],
"devman_portability.html#secproblems_and_workarounds":[3,12,4],
"devman_portability.html#secusing_version_macros":[3,12,2],
"devman_portability.html#secvarious_problems":[3,12,4,2],
"devman_portability.html#secwhich_compiler":[3,12,3],
"devman_portability.html#secworkaround_flags":[3,12,4,0],
"devman_portability.html#secworkaround_macros":[3,12,4,1],
"devman_reference_counting.html":[3,5],
"devman_reference_counting.html#Developer_manualAllocation":[3,5,5],
"devman_reference_counting.html#Developer_manualHandleRep":[3,5,1],
"devman_reference_counting.html#Developer_manualReferencecounting":[3,5,0],
"devman_reference_counting.html#Developer_manualTemplatedhandles":[3,5,3],
"devman_reference_counting.html#Developer_manualUsingHandleRep":[3,5,2],
"devman_reference_counting.html#Developer_manualUsingtemplatedhandles":[3,5,4],
"devman_robustness.html":[3,11],
"devman_robustness.html#Developer_manualRequirementsandrecommendations":[3,11,1],
"devman_robustness.html#Developer_manualTheroleofpredicatesandconstructions":[3,11,0],
"devman_submission.html":[3,15],
"devman_testing.html":[3,14],
"devman_testing.html#pkgTestsuite":[3,14,0],
"devman_traits_classes.html":[3,3],
"devman_traits_classes.html#seckernel_traits":[3,3,3],
"devman_traits_classes.html#sectraits_class_example":[3,3,2],
"devman_traits_classes.html#sectraits_class_req_and_rec":[3,3,4],
"devman_traits_classes.html#secwhat_is_a_traits_class":[3,3,0],
"devman_traits_classes.html#secwhy_traits_classes":[3,3,1],
"devman_traits_classes.html#subseccgal_traits_classes":[3,3,2,1],
"devman_traits_classes.html#subsectraits_class_requirements":[3,3,2,0],
"general_intro.html":[0],
"how_to_cite_cgal.html":[6],
"index.html":[],
"installation.html":[0,5],
"installation.html#installation_buildprogram":[0,5,4],
"installation.html#installation_cgalconfig":[0,5,1,6],
"installation.html#installation_configuring_cmd":[0,5,1,5],
"installation.html#installation_configuring_gui":[0,5,1,4],
"installation.html#installation_configwithcmake":[0,5,1],
"installation.html#installation_debugrelease":[0,5,1,2],
"installation.html#installation_examples":[0,5,1,1],
"installation.html#installation_idealworld":[0,5,0],
"installation.html#installation_miscvariables":[0,5,1,3],
"installation.html#seccmakeoutofsource":[0,5,2],
"installation.html#secinstalling":[0,5,3],
"installation.html#seclibraries":[0,5,1,0],
"installation.html#ssec_installation_build_ex_demos":[0,5,2,0],
"license.html":[0,8],
"license.html":[4],
"license.html#licenseCheck":[4,4],
"license.html#licenseCheck":[0,8,4],
"license.html#licensesCommercial":[0,8,3],
"license.html#licensesCommercial":[4,3],
"license.html#licensesGPL":[4,0],
"license.html#licensesGPL":[0,8,0],
"license.html#licensesLGPL":[4,1],
"license.html#licensesLGPL":[0,8,1],
"license.html#licensesRationale":[0,8,2],
"license.html#licensesRationale":[4,2],
"license.html#licensesWhere":[0,8,5],
"license.html#licensesWhere":[4,5],
"manual.html":[0,6],
"manual.html#advanced_features":[0,6,2,0],
"manual.html#debugging_support":[0,6,2,1],
"manual.html#deprecated_code":[0,6,2,2],
"manual.html#markingSpecialFunctionality":[0,6,2],
"manual.html#secorganization":[0,6,0],
"manual.html#secorganizationref":[0,6,1],
"md_Doxygen_for_CGAL.html":[5],
"packages.html":[2],
"packages.html#Miscellany":[2,15,8],
"packages.html#PartAlgebraicFoundations":[2,0],
"packages.html#PartArrangements":[2,6],
"packages.html#PartCombinatorialAlgorithms":[2,1],
"packages.html#PartConvexHullAlgorithms":[2,3],
"packages.html#PartGeometricOptimization":[2,13],
"packages.html#PartGeometryProcessing":[2,11],
"packages.html#PartInterpolation":[2,14],
"packages.html#PartKernels":[2,2],
"packages.html#PartMeshing":[2,9],
"packages.html#PartPolygons":[2,4],
"packages.html#PartPolyhedra":[2,5],
"packages.html#PartReconstruction":[2,10],
"packages.html#PartSearchStructures":[2,12],
"packages.html#PartSupportLibrary":[2,15],
"packages.html#PartTriangulationsAndDelaunayTriangulations":[2,7],
"packages.html#PartVisualization":[2,16],
"packages.html#PartVoronoiDiagrams":[2,8],
"packages.html#PkgAABBTree":[2,12,5],
"packages.html#PkgAdvancingFrontSurfaceReconstruction":[2,10,2],
"packages.html#PkgAlgebraicFoundations":[2,0,0],
"packages.html#PkgAlgebraicKernelD":[2,0,4],
"packages.html#PkgAlphaShapes2":[2,7,12],
"packages.html#PkgAlphaShapes3":[2,7,13],
"packages.html#PkgAlphaWrap3":[2,9,8],
"packages.html#PkgApolloniusGraph2":[2,8,2],
"packages.html#PkgArrangementOnSurface2":[2,6,0],
"packages.html#PkgBGL":[2,15,1],
"packages.html#PkgBarycentricCoordinates2":[2,14,1],
"packages.html#PkgBasicViewer":[2,16,2],
"packages.html#PkgBooleanSetOperations2":[2,4,2],
"packages.html#PkgBoundingVolumes":[2,13,0],
"packages.html#PkgBoxIntersectionD":[2,12,4],
"packages.html#PkgCGALIpelets":[2,16,1],
"packages.html#PkgCircularKernel2":[2,2,2],
"packages.html#PkgCircularKernel3":[2,2,3],
"packages.html#PkgClassification":[2,11,16],
"packages.html#PkgCombinatorialMaps":[2,5,3],
"packages.html#PkgConeSpanners2":[2,15,5],
"packages.html#PkgConstrainedTriangulation3":[2,7,9],
"packages.html#PkgConvexDecomposition3":[2,5,7],
"packages.html#PkgConvexHull2":[2,3,0],
"packages.html#PkgConvexHull3":[2,3,1],
"packages.html#PkgConvexHullD":[2,3,2],
"packages.html#PkgEnvelope2":[2,6,3],
"packages.html#PkgEnvelope3":[2,6,4],
"packages.html#PkgFrechetDistance":[2,4,9],
"packages.html#PkgGeneralizedMaps":[2,5,4],
"packages.html#PkgGenerators":[2,15,7],
"packages.html#PkgGraphicsView":[2,16,0],
"packages.html#PkgHalfedgeDS":[2,5,1],
"packages.html#PkgHandlesAndCirculators":[2,15,6],
"packages.html#PkgHeatMethod":[2,11,17],
"packages.html#PkgHyperbolicSurfaceTriangulation2":[2,7,5],
"packages.html#PkgHyperbolicTriangulation2":[2,7,4],
"packages.html#PkgInscribedAreas":[2,13,1],
"packages.html#PkgInterpolation2":[2,14,0],
"packages.html#PkgIntervalSkipList":[2,12,1],
"packages.html#PkgIsosurfacing3":[2,9,5],
"packages.html#PkgJetFitting3":[2,11,10],
"packages.html#PkgKernel23":[2,2,0],
"packages.html#PkgKernelD":[2,2,1],
"packages.html#PkgKineticSpacePartition":[2,10,4],
"packages.html#PkgKineticSurfaceReconstruction":[2,10,5],
"packages.html#PkgLinearCellComplex":[2,5,5],
"packages.html#PkgMatrixSearch":[2,1,0],
"packages.html#PkgMesh2":[2,9,0],
"packages.html#PkgMesh3":[2,9,4],
"packages.html#PkgMinkowskiSum2":[2,4,7],
"packages.html#PkgMinkowskiSum3":[2,5,8],
"packages.html#PkgModularArithmetic":[2,0,2],
"packages.html#PkgNef2":[2,4,3],
"packages.html#PkgNef3":[2,5,6],
"packages.html#PkgNefS2":[2,4,4],
"packages.html#PkgNumberTypes":[2,0,1],
"packages.html#PkgOptimalBoundingBox":[2,13,4],
"packages.html#PkgOptimalTransportationReconstruction2":[2,10,6],
"packages.html#PkgOrthtree":[2,12,6],
"packages.html#PkgPartition2":[2,4,5],
"packages.html#PkgPeriodic2Triangulation2":[2,7,3],
"packages.html#PkgPeriodic3Mesh3":[2,9,7]
};
